>From 2e70ff1704f798930781241b5686c2cf0e58f198 Mon Sep 17 00:00:00 2001
From: Erwan Tulou <erwan10@videolan.org>
Date: Sat, 2 Jan 2010 23:09:36 +0100
Subject: [PATCH] core: correct memory leak

var_Change with VLC_VAR_SETVALUE showed a memory leak when dealing with a STRING variable.
The pf_dup function must not be called directy with a parameter passed by the caller.
otherwise, a reference is lost (memory leak)
---
 src/misc/variables.c |    8 +++++---
 1 files changed, 5 insertions(+), 3 deletions(-)

diff --git a/src/misc/variables.c b/src/misc/variables.c
index 355f30e..baae537 100644
--- a/src/misc/variables.c
+++ b/src/misc/variables.c
@@ -417,6 +417,7 @@ int __var_Change( vlc_object_t *p_this, const char *psz_name,
     int i_var, i;
     variable_t *p_var;
     vlc_value_t oldval;
+    vlc_value_t newval;
 
     assert( p_this );
 
@@ -572,13 +573,14 @@ int __var_Change( vlc_object_t *p_this, const char *psz_name,
             break;
         case VLC_VAR_SETVALUE:
             /* Duplicate data if needed */
-            p_var->ops->pf_dup( p_val );
+            newval = *p_val;
+            p_var->ops->pf_dup( &newval );
             /* Backup needed stuff */
             oldval = p_var->val;
             /* Check boundaries and list */
-            CheckValue( p_var, p_val );
+            CheckValue( p_var, &newval );
             /* Set the variable */
-            p_var->val = *p_val;
+            p_var->val = newval;
             /* Free data if needed */
             p_var->ops->pf_free( &oldval );
             break;
-- 
1.5.6.5

